#!/bin/bash

# -----------------------------------------------------
# Aplica configuració Linkat a OpenSuse 11.4
#
# -----------------------------------------------------

# Preguntem si es vol iniciar la transformació
/usr/bin/zenity --question --text "Vols transformar aquest ordinador en un servidor de centre Linkat?" --title "Servidor de Centre Linkat"
if [ $? -gt 0 ] ; then
    exit 1
fi

LOG=/var/log/linkat-install.log
date >> $LOG

# Eliminem els repositoris existents
rm /etc/zypp/repos.d/*

# Afegim els repositoris de la Linkat
/usr/bin/zypper ar -f http://download-linkat.xtec.cat/distribution/linkat-edu-11.4/inst-source/extres/ Extres
/usr/bin/zypper ar -f http://download-linkat.xtec.cat/distribution/linkat-edu-11.4/inst-source/linkat4-edu/ Inst-sources
/usr/bin/zypper ar -f http://download-linkat.xtec.cat/distribution/linkat-edu-11.4/updates/linkat4/ Updates
/usr/bin/zypper ar -f http://download-linkat.xtec.cat/distribution/linkat-edu-11.4/updates/linkat4-edu/ Updates-edu
/usr/bin/zypper ar -f http://download-linkat.xtec.cat/distribution/linkat-edu-11.4/mirrors/openSUSE_11.4/updates/ Updates-OpenSUSE
/usr/bin/zypper ar -f http://download-linkat.xtec.cat/distribution/linkat-edu-11.4/mirrors/openSUSE_11.4_EDU/ OpenSUSE-EDU
/usr/bin/zypper ar -f http://download-linkat.xtec.cat/distribution/linkat-edu-11.4/mirrors/openSUSE_11.4/inst-source/oss/ OSS
/usr/bin/zypper ar -f http://download-linkat.xtec.cat/distribution/linkat-edu-11.4/mirrors/openSUSE_11.4/inst-source/non-oss/ NON-OSS
/usr/bin/zypper ar -f http://download-linkat.xtec.cat/distribution/linkat-edu-11.4/mirrors/mozilla/ Mozilla

# Paquets a eliminar
rpm -e --nodeps nspluginwrapper 
rpm -e --nodeps bootsplash-branding-openSUSE 
rpm -e --nodeps gfxboot-branding-openSUSE 
rpm -e --nodeps gconf2-branding-openSUSE 
rpm -e --nodeps branding-openSUSE 
rpm -e --nodeps gnome-menus-branding-openSUSE 
rpm -e --nodeps gdm-branding-openSUSE 
rpm -e --nodeps gtk2-branding-openSUSE 
rpm -e --nodeps java-1_6_0-openjdk-plugin 
rpm -e --nodeps libffi45 
rpm -e --nodeps java-1_6_0-openjdk

# Comprovem la connectivitat i actualitzem els repositoris
killall -9 gpk-update-viewer 

/usr/bin/zypper --gpg-auto-import-keys ref
if [ $? -gt 0 ] ; then
	echo "Error de connexió amb els repositoris, el programa es tancarà"  >> $LOG
        /usr/bin/zenity --error --text "La instal·lació ha fallat!"
	exit 1
fi

# Paquets a instal·lar
/usr/bin/zypper install -y gconf2-branding-Linkat-Edu
/usr/bin/zypper install -y bootsplash-branding-Linkat 
/usr/bin/zypper install -y branding-Linkat 
/usr/bin/zypper install -y desktop-data-Linkat 
/usr/bin/zypper install -y edu365 
/usr/bin/zypper install -y filezilla 
/usr/bin/zypper install -y gdm-branding-Linkat 
/usr/bin/zypper install -y gfxboot-branding-Linkat 
/usr/bin/zypper install -y gnome-menus-branding-Linkat 
/usr/bin/zypper install -y gtk2-branding-Linkat 
/usr/bin/zypper install -y iSeriesAccess-icon-linkat 
/usr/bin/zypper install -y linkat4artwork 
/usr/bin/zypper install -y java-1_6_0-sun 
/usr/bin/zypper install -y java-1_6_0-sun-plugin 
/usr/bin/zypper install -y reportcups 
/usr/bin/zypper install -y jclic 
/usr/bin/zypper install -y jclic-projects
/usr/bin/zypper install -y linkat-fix-edu
/usr/bin/zypper install -y server_configuration
if [ $? -gt 0 ] ; then
        echo "El servidor no s'ha pogut instal·lar, el programa es tancarà"  >> $LOG
        /usr/bin/zenity --error --text "La instal·lació ha fallat!"
        exit 1
fi


# Fem que el Java per defecte sigui el de Sun
update-alternatives --set javaplugin /usr/lib/jvm/java-1.6.0-sun-1.6.0/jre/lib/i386/libnpjp2.so >> $LOG
update-alternatives --set java /usr/lib/jvm/jre-1.6.0-sun/bin/java >> $LOG
update-alternatives --set jre_1.6.0 /usr/lib/jvm/jre-1.6.0-sun >> $LOG

# Canviem la icona de la pantalla d'entrada al gnome
/usr/bin/sudo -u gdm /usr/bin/dbus-launch /usr/bin/gconftool-2 --set /apps/gdm/simple-greeter/logo_icon_name --type string gdm-suse  >> $LOG

# apliquem imatge de fons del grub
/usr/sbin/gfxboot --add-file /etc/bootsplash/themes/Linkat/cdrom/back.jpg >> $LOG

# Apliquem el tema de la Linkat al Bootsplash
/usr/bin/sed -i "s/THEME=\"openSUSE\"/THEME=\"Linkat\"/g" /etc/sysconfig/bootsplash >> $LOG

# Afegim la línia del tema bootsplash Linkat al SUSEconfig
echo "# Tema Linkat al Bootsplash " >> /sbin/conf.d/SuSEconfig.xLinkat-fix-edu >> $LOG
echo 'sed -i "s/THEME=\"openSUSE\"/THEME=\"Linkat\"/g" /etc/sysconfig/bootsplash' >> /sbin/conf.d/SuSEconfig.xLinkat-fix-edu >> $LOG

# corregim una possible errada en els noms dels directoris d'usuari
/usr/bin/sed -i "s/DOWNLOAD=Downloads/DOWNLOAD=Download/g" /etc/xdg/user-dirs.defaults >> $LOG

# corregim noms de la icona del firefox a la barra suprior de l'escriptori
/usr/bin/sed -i "s/MozillaFirefox.desktop/firefox.desktop/g" /etc/gconf/gconf.xml.vendor/%gconf-tree.xml >> $LOG

# actualitzem icones
/usr/bin/gtk-update-icon-cache >> $LOG

# preparem el nucli d'inici del sistema
/sbin/mkinitrd >> $LOG

# ajustem els nivells del "menú tradicional del gnome"
cd /etc/xdg/menus >> $LOG
/usr/bin/wget http://download-linkat.xtec.cat/distribution/linkat-edu-11.4/scripts/prefs/linkat4-applications.menu >> $LOG
/bin/cp -n gnome-applications.menu gnome-applications.menu.original >> $LOG
/bin/cp linkat4-applications.menu gnome-applications.menu >> $LOG

# establim la pàgina d'inici del Firefox i afegim cercadors i preferits personalitzats
cd /usr/lib/firefox >> $LOG
/usr/bin/wget http://download-linkat.xtec.cat/distribution/linkat-edu-11.4/scripts/prefs/browserconfig.properties.linkat >> $LOG
/bin/cp -n browserconfig.properties browserconfig.properties.original >> $LOG
/bin/cp browserconfig.properties.linkat browserconfig.properties >> $LOG

cd /usr/lib/firefox/searchplugins >> $LOG
/usr/bin/wget http://download-linkat.xtec.cat/distribution/linkat-edu-11.4/scripts/prefs/merli.xml >> $LOG

cd /usr/lib/firefox/defaults/profile
/usr/bin/wget http://download-linkat.xtec.cat/distribution/linkat-edu-11.4/scripts/prefs/bookmarks.html.linkat >> $LOG
/bin/cp -n bookmarks.html bookmarks.html.original >> $LOG
/bin/cp bookmarks.html.linkat bookmarks.html >> $LOG

/sbin/conf.d/SuSEconfig.xLinkat-fix-edu

/usr/bin/zypper up -y

rpm -qa server_configuration
if [ $? -eq 0 ] ; then
	rpm -e --nodeps linkat-install-server
        /usr/bin/zenity --info --title="Transformació finalitzada" --text "La transformació ha finalitzat, és necessari reiniciar l'ordinador.\n\nPer configurar el servidor de centre s'ha d'executar l'ordre següent:\n/etc/Linkat/Linkat.sh install"
	exit 0
else
	echo "No s'ha pogut instal·lar correctament el servidor de centre Linkat" >> $LOG
        /usr/bin/zenity --error --text "La instal·lació ha fallat!"
	exit 1
fi
